@@ -8,7 +8,7 @@ from isodate import duration_isoformat
 
 from gateways.apis.api_route_base import ApiRoot
 from gateways.common.cs18_api_classes import BlueprintRepositoryDetails, AccessLink, \
-    AddAccountBlueprintRepositoryRequest
+    AddBlueprintUsingTokenRepositoryRequest, AddBlueprintGithubRepositoryRequest, AddBlueprintBitbucketRepositoryRequest
 from gateways.common.cs18_api_converters import Converters
 from gateways.common.cs18_api_errors import UnauthorizedException, SandboxNotFound, \
     SandboxEndingFailed
@@ -482,26 +482,32 @@ class Colony:
                         lazy_load_artifacts_timeout: int
         """
         method_url = self._api_root.sandbox.sandboxes()
-        scheduled_end_time = (
-            datetime.isoformat(kwargs.get("scheduled_end_time"))
-            if kwargs.get("scheduled_end_time")
-            else None
-        )
-        duration = duration_isoformat(kwargs.get("duration")) if kwargs.get("duration") else None
+        request = {
+            "blueprint_name": blueprint_name,
+            "sandbox_name": sandbox_name,
+            "artifacts": kwargs.get("artifacts", {}),
+            "inputs": kwargs.get("inputs", {}),
+            "automation": kwargs.get("automation", False),
+            "compute_availability": kwargs.get("compute_availability"),
+            "lazy_load_artifacts": kwargs.get("lazy_load_artifacts", False),
+            "lazy_load_artifacts_timeout": kwargs.get("lazy_load_artifacts_timeout", 0),
+        }
+
+        if kwargs.get("scheduled_end_time"):
+            request["scheduled_end_time"] = datetime.isoformat(kwargs.get("scheduled_end_time"))
+
+        if kwargs.get("duration"):
+            request["duration"] = duration_isoformat(kwargs.get("duration"))
+
+        if "branch" in kwargs or "commit" in kwargs:
+            request["source"] = {
+                "branch": kwargs.get("branch"),
+                "commit": kwargs.get("commit"),
+            }
+
         resp = self.session.post(
             url=method_url,
-            json={
-                "blueprint_name": blueprint_name,
-                "sandbox_name": sandbox_name,
-                "artifacts": kwargs.get("artifacts", {}),
-                "inputs": kwargs.get("inputs", {}),
-                "automation": kwargs.get("automation", False),
-                "scheduled_end_time": scheduled_end_time,
-                "duration": duration,
-                "compute_availability": kwargs.get("compute_availability"),
-                "lazy_load_artifacts": kwargs.get("lazy_load_artifacts", False),
-                "lazy_load_artifacts_timeout": kwargs.get("lazy_load_artifacts_timeout", 0),
-            },
+            json=request,
         )
         GatewayUtils.handle_response(response=resp, return_codes=[202])
         result = json.loads(resp.text)
@@ -591,12 +597,27 @@ class Colony:
         production_response = Converters.create_production_green_response(json_result)
         return production_response
 
-    def add_repository_to_account(self, request: AddAccountBlueprintRepositoryRequest):
+    def add_account_blueprint_repository_using_token(self, request: AddBlueprintUsingTokenRepositoryRequest):
         method_url = self._api_root.settings.add_repository_by_token()
         resp = self.session.post(url=method_url, json=request.__dict__)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
-    def get_account_repositories(self) -> List[AccountRepositoryResponse]:
+    def add_account_blueprint_github_repository(self, request: AddBlueprintGithubRepositoryRequest):
+        method_url = self._api_root.settings.add_github_repository()
+        resp = self.session.post(url=method_url, json=request.__dict__)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+    def add_account_blueprint_bitbucket_repository(self, request: AddBlueprintBitbucketRepositoryRequest):
+        method_url = self._api_root.settings.add_bitbucket_repository()
+        resp = self.session.post(url=method_url, json=request.__dict__)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+    def delete_account_blueprint_repository(self, name: str):
+        method_url = self._api_root.settings.repository(name)
+        resp = self.session.delete(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+    def get_account_blueprint_repositories(self) -> List[AccountRepositoryResponse]:
         url = self._api_root.settings.repositories()
         response = self.session.get(url=url)
         GatewayUtils.handle_response(response=response, return_codes=[200])
@@ -604,11 +625,6 @@ class Colony:
         repositories_json = json.loads(response.text)
         return [Converters.create_account_repository_response(repository) for repository in repositories_json]
 
-    def delete_account_repository(self, name: str):
-        method_url = self._api_root.settings.repository(name)
-        resp = self.session.delete(url=method_url)
-        GatewayUtils.handle_response(response=resp, return_codes=[200])
-
     def add_repository_to_space(
             self,
             repository_details: BlueprintRepositoryDetails,
