@@ -89,3 +89,16 @@ class CreateAccountRequest:
 class UpdateSpaceRequest:
     def __init__(self, name: str):
         self.name = name
+
+
+class AddK8SComputeServiceToSpaceRequest:
+    def __init__(self, name: str, namespace: str, internet_facing: bool) -> None:
+        self.name = name
+        self.namespace = namespace
+        self.internet_facing = internet_facing
+
+
+class UpdateK8SComputeServiceInSpaceRequest:
+    def __init__(self, namespace: str, internet_facing: bool) -> None:
+        self.namespace = namespace
+        self.internet_facing = internet_facing
